/***********************************
 This command file illustrates using
 SAS for basic data setup and
 variable creation.

filename: brieftour.sas
************************************/

OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";

/*****************Read in raw data************************/
data class;
	infile "class.dat";
	input lname $ sex $ age height sbp;
run;


/*************Fixed Column Data****************************/
data flights;
	infile "marflt.dat" ;
	input flight 1-3 depart $ 15-17 dest $ 18-20 boarded 34-36;
run;

/****************Create a permanent SAS dataset********************/
libname mylib "C:\Users\kwelch\Desktop\labdata";

data mylib.flights;
	infile "marflt.dat" ;
	input flight 1-3 depart $ 15-17 dest $ 18-20 boarded 34-36;
run;
proc means data=mylib.flights;
run;


/****************Import data from Excel*************/
PROC IMPORT OUT=pulse 
            DATAFILE="C:\Users\kwelch\Desktop\LabData\PULSE.XLS"
            DBMS= xls REPLACE; 
            SHEET="pulse"; 
RUN;


/*************Use a permanent SAS dataset*****************/
libname sasdata2 "C:\Users\kwelch\Desktop\sasdata2";

proc contents data=sasdata2.employee;
run;

proc means data=sasdata2.employee;
run;

proc freq data=sasdata2.employee;
  tables gender jobcat;
run;

/*Select cases for analysis*/
proc print data=sasdata2.employee;
  where jobcat=1;
run;

/*User-defined formats*/
proc format;
  value $genderfmt "f"="Female"
                   "m"="Male";
  value jobcatfmt 1="Clerical"
                  2="Custodial"
				  3="Managerial";
run;

proc freq data=sasdata2.employee;
  tables gender jobcat bdate;
  format gender $genderfmt. jobcat jobcatfmt.;
run;

/*User-defined and SAS formats*/
proc print data=sasdata2.employee;
  where jobcat=1;
  format bdate mmddyy10. salary salbegin dollar12. gender $genderfmt.  
         jobcat jobcatfmt.;
run;

/***********Generate new variables in a SAS dataset***************/

data sasdata2.employee2;
  set sasdata2.employee;
  currentyear=2005;
  alpha ="A"; 
  datevar = "05OCT2012"D; 
  format datevar mmddyy10.;
  saldiff = salary - salbegin;
  if (salary > 50000) then salcat = "A" ;
  else salcat = "B";
  if salary = . then salcat = " ";
  format bdate mmddyy10. salary salbegin dollar12.;

if gender="f" then female=1;
if gender="m" then female=0;

if jobcat not=. then do;
   jobdum1 = (jobcat=1);
   jobdum2 = (jobcat=2);
   jobdum3 = (jobcat=3);
end;

nmiss = nmiss(of educ--salbegin);
salmean = mean(salary, salbegin);
run;


/**********Permanent Formats***********/

proc format lib=sasdata2;
  value jobcatfmt 1="Clerical" 2="Custodial" 3="Manager";
  value $genderfmt "f" = "Female"
                   "m" = "Male";
  value minfmt  1="Yes"
                0="No";
run;

options fmtsearch=(work sasdata2);

proc datasets lib=sasdata2;
  modify employee2;
  format jobcat jobcatfmt. gender $genderfmt. minority minfmt.;
run;
proc contents data=sasdata2.employee2;
run;

/*Use the formatted data later*/
options nofmterr;
libname sasdata2 "C:\Users\kwelch\Desktop\sasdata2";
options fmtsearch=(work sasdata2);

proc means data=sasdata2.employee2;
  class jobcat;
  var saldiff;
run;


/*********Sort data**********/

proc sort data=sasdata2.employee2;
  by gender;
run;
proc means data=sasdata2.employee2;
  by gender;
run;

/*Sort by a continuous variable*/
proc sort data=sasdata2.employee2;
  by salary;
run;
proc contents data=sasdata2.employee2;
run;

/*Sort in descending order*/
proc sort data=sasdata2.employee2;
  by gender descending salary;
run;

proc print data=sasdata2.employee2(obs=25);
run;

/********************************************
 Statistical Analyses
*********************************************/

/*Cross-tab with chi-square test*/
proc freq data=sasdata2.employee2;
   tables gender*jobcat / chisq;
run;

/*Independent samples t-test*/
proc ttest data=sasdata2.employee2;
  class gender;
  var salary;
run;

/*t-test by groups*/
proc sort data=sasdata2.employee;
  by jobcat;
run;
proc ttest data=sasdata2.employee;
  by jobcat;
  class gender;
  var salary;
run;

/*Correlation*/
proc corr data=sasdata2.employee;
  var salary salbegin educ;
run;

/*Linear Regression*/
ods graphics on;
proc reg data=sasdata2.employee2;
  model salary = salbegin educ jobdum2 jobdum3 prevexp female;
run; quit;
ods graphics off;

/*Logistic Regression*/

options pagesize=80;
ods graphics on;
proc logistic data=sasdata2.afifi descending plots=(roc effect);
  model died = map1 shock;
run;
ods graphics off;

/**********************************************
  Statistical Graphics
***********************************************/

/*Enable the ODS Graphics Editor*/
ods listing sge = on;

/************************************************
  Change the path to mylib to the folder where
  you have stored your SAS datasets,
  Employee.sas7bdat, and Autism.sas7bdat
  e.g., for the desktop:
  libname mylib "C:\Users\kwelch\Desktop\sasdata2";
*************************************************/
libname mylib "C:\Users\kwelch\Desktop\sasdata2";

/*Boxplots*/
title "Boxplot";
title2 "No Categories";
proc sgplot data=mylib.employee;
  vbox salary;
run; 

title "Boxplot";
title2 "Category=Gender";
proc sgplot data=sasdata2.employee;
  vbox salary/ category=gender;
run; 

title "Boxplot with Panels";
proc sgpanel data=sasdata2.employee;
  panelby jobcat / rows=1 columns=3 ;
  vbox salary / category= gender;
run;

/*Barcharts*/

title "Vertical Bar Chart";
proc sgplot data=sasdata2.employee;
  vbar jobcat ;
run;

title "Vertical Bar Chart";
title2 "Clustered by Gender";
proc sgplot data=mylib.employee;
  vbar jobcat /group=Gender groupdisplay=cluster ;
run;

title "BarChart with Mean and Standard Deviation";
proc sgplot data=sasdata2.employee;
  vbar jobcat / response=salary limitstat = stddev
  limits = upper stat=mean;
run;
 

/*Histograms*/
title "Histogram With Density Overlaid";
proc sgplot data=sasdata2.employee;
  histogram salary ;
  density salary;
  density salary / type=kernel;
  keylegend / location = inside position = topright; 
run;

/*Scatterplots*/

title "Scatterplot";
proc sgplot data=sasdata2.employee;
  scatter x=salbegin y=salary / group=gender ;
run;

title "Scatterplot with Regression Line";
title2 "Clerical Only";
proc sgplot data=sasdata2.employee;
  where jobcat=1;
  scatter x=prevexp y=salary / group=gender ;
  reg x=prevexp y=salary / cli clm nomarkers;
run;

title "Scatterplot with Regression Line";
title2 "Separate Lines for Females and Males";
proc sgplot data=sasdata2.employee;
  where jobcat=1;
  reg x=prevexp y=salary / group=gender;
run;
 
title "Scatterplot Matrix"; 
title2 "Clerical Employees";
proc sgscatter data=sasdata2.employee;
  where jobcat=1;
  matrix salbegin salary jobtime prevexp / group=gender
                   diagonal=(histogram kernel);
run;

/*Using formats to make graphs more readable*/

proc format;
   value jobcat 1="Clerical"
                2="Custodial"
	            3="Manager";
   value $Gender "f"="Female"
                 "m"="Male";
run;

title "Boxplot with Panels";
proc sgpanel data=sasdata2.employee;
  panelby jobcat / rows=1 columns=3 novarname;
  vbox salary / category= gender ;
  format gender $gender.;
  format jobcat jobcat.;
run;


/*************************************************
  Traditional SAS Graphics
**************************************************/
/*Creating a Histogram Using Proc Univariate*/

title "Distribution of Salary";
proc univariate data=sasdata2.employee noprint;
  var salary;
  histogram;
run;

symbol1 value=dot height=.5 interpol=rl ;
title "Regression Plot for Salary";
proc gplot data=sasdata2.employee;
  plot salary * prevexp ;
run; quit;



