/************************************************
 THIS COMMAND FILE ILLUSTRATES HOW TO CREATE
 AND USE BASIC MACROS IN SAS.

 FILENAME: USE_MACRO.SAS
*************************************************/
OPTIONS FORMCHAR="|----|+|---+=|-/\<>*";
OPTIONS PAGENO=1 NODATE;

DATA AFIFI;
    INFILE "AFIFI.DAT";
    INPUT
    #1 IDNUM 1-4 AGE 5-8 SEX 13-15 SURVIVE 16 SHOKTYPE 17-20 SBP1 21-24
       MAP1 25-28 HEART1 29-32 CARDIAC1 45-48 2 URINE1 57-60 HGB1 69-72 1
    #2 SBP2 21-24 MAP2 25-28 HEART2 29-32 CARDIAC2 45-48 2 URINE2 57-60
       HGB2 69-72 1;

    LABEL SHOCK="Shock type"
       SBP1="Systolic BP t1"
       SBP2="Systolic BP t2"
       MAP1="Mean arterial pressure t1"
       MAP2="Mean arterial pressure t2"
       HEART1="Heart rate t1"
       HEART2="Heart rate t2"
       CARDIAC1="Cardiac index t1"
       CARDIAC2="Cardiac index t2"
       URINE1="Urinary output t1"
       URINE2="Urinary output t2"
       HGB1="Hemoglobin t1"
       HGB2="Hemoglobin t2" ;

    IF SHOKTYPE=2 THEN SHOCK=1;
    IF SHOKTYPE IN (3,4,5,6,7) THEN SHOCK=2;
    SBPDIFF=SBP2-SBP1;
RUN;

PROC FORMAT ;
    VALUE SURVFMT 1="1:Lived" 3="3:Died" ;
    VALUE SHOCKFMT 1="1:No shock" 2="2:Shock" ;
    VALUE SEXFMT 1="1:Male" 2="2:Female" ;
RUN;

/*SET UP AND RUN THE MACRO*/

options mprint mlogic symbolgen;

%macro anal(dsn,depvar,indvar);
proc reg data=&dsn;
  model &depvar = &indvar;
title "Regression of &depvar on &indvar";
run; 
quit;
%mend anal;

%anal(afifi,sbp2,cardiac1)
%anal(afifi,sbp2,heart1)
%anal(afifi,sbp2,map1)
%anal(afifi,sbp2,cardiac1 heart1 map1)


/********************************************
  Project Setup for several people
*********************************************/

/*First, create the data set from which we will sample*/

data project;
  infile "project.dat";
  input 
V1		    1-4
V6		    5
V7	        7-8
V31 		11
V1109		12
V1270		13-17 
V1273		18-20
V1274		21-23
V3015		24-25
V3250       26-30 
V3251       31-33
;
label v1 = "Case Number"
      v6 = "Sex"
      v7 = "Age CVI"
      v31 = "Exam Status"
      v1109 = "Cig Smoking CV I"
      v1270 = "Ounces ethanol CV I"
      v1273 = "Weight kg CV I"
      v1274 = "Height cm CV I"
      v3015 = "Cigarettes per day CV III"
      v3250 = "Weight kg CV III"
      v3251 = "Height cm CV III";

random = ranuni(12447);
run;

/*Randomize the data by sorting by a random variable*/
proc sort data=project;
 by random;
run;

/*Create the macro to bring in names,
    Select a sample for each person
    Get Descriptives
    Write out a sample data set*/

options mprint nosymbolgen nomlogic;
%macro sample(num=);
title;
data names;
  infile "lastname.txt";
  length lname $10;
  input lname $ ;
call symput('name'||left(_n_),trim(lname));
run;

%do i=1 %to &num;

proc surveyselect data=project method=srs 
     sampsize=400 out=sample&i;
run;
proc means data=sample&i;
title "Descriptives for &name&i";
run;

filename out&i 
   "c:\documents and settings\kathy\desktop\&name&i...dat";
data _null_;
   set sample&i;
   file out&i;
  put
  V1		1-4
  V6		5
  V7	    7-8
  V31 		11
  V1109		12
  V1270		13-17 1
  V1273		18-20
  V1274		21-23
  V3015		24-25
  V3250     26-30 1
  V3251     31-33;
run;

%end;
%mend;



%sample(num=3);



/************************************************************
  USING THE GLIMMIX MACRO TO ESTIMATE A RANDOM EFFECTS MODEL
  FOR A BINARY DEPENDENT VARIABLE
**************************************************************/

/*IMPORT THE BMI.XLS EXCEL FILE*/
PROC IMPORT OUT= WORK.bmi 
            DATAFILE= "bmi.xls" 
            DBMS=EXCEL2000 REPLACE;
     GETNAMES=YES;
RUN;
proc means data=bmi;
run;
proc freq data=bmi;
  tables time*cig;
run;

filename glmm "glimmix.sas";
%include glmm;

%glimmix(data=bmi, procopt=noclprint,
   stmts=%str(
  class id time sex;
  model cig  = time sex age/ solution;
  repeated time / subject=id type=cs;
  lsmeans time / cl diff;),
  error=binomial
   )




